@@ -1,5 +1,5 @@
 package Bio::Tradis::CombinePlots;
-$Bio::Tradis::CombinePlots::VERSION = '1.3.1';
+$Bio::Tradis::CombinePlots::VERSION = '1.3.2';
 # ABSTRACT: Combine multiple plotfiles and generate updated statistics for the combined files
 
 
@@ -309,7 +309,7 @@ Bio::Tradis::CombinePlots - Combine multiple plotfiles and generate updated stat
 
 =head1 VERSION
 
-version 1.3.1
+version 1.3.2
 
 =head1 SYNOPSIS
 
@@ -324,11 +324,12 @@ For example, an input file named plots_to_combine.txt:
     tradis3 plot3.1.gz  plot3.2.gz plot3.3.gz   plot3.4.gz
 
 will produce 
+
 =over
 
-=item 1. a directory named combined with 3 files - tradis1.insertion_site_plot.gz,
+1. a directory named combined with 3 files - tradis1.insertion_site_plot.gz,
 tradis2.insertion_site_plot.gz, tradis3.insertion_site_plot.gz
-=item 2. a stats file named plots_to_combine.stats
+2. a stats file named plots_to_combine.stats
 
 =back
 
